.. _api:

=============
API reference
=============

This section gives an overview of the API for atomate2.

.. currentmodule:: atomate2

.. autosummary::
   :recursive:
   :toctree:
   :nosignatures:

   amset
   common
   settings
   utils
   vasp
